********************************************************************
* This do-file takes as input: main_dataset_clean.dta
* It runs wage regressions to generate gender-specific occupation wage premia
********************************************************************

***********************************************************************
use "Built/main_dataset_clean", clear

*** Keep only the employed
keep if emp==1

*** Generate age group indicator
gen age_grp=1 if age>=20 & age<=24
replace age_grp=2 if age>=25 & age<=29
replace age_grp=3 if age>=30 & age<=34
replace age_grp=4 if age>=35 & age<=39
replace age_grp=5 if age>=40 & age<=44
replace age_grp=6 if age>=45 & age<=49
replace age_grp=7 if age>=50 & age<=54
replace age_grp=8 if age>=55 & age<=59
replace age_grp=9 if age>=60 & age<=64
*** Create age group dummies 
quietly tab age_grp, gen(age_)

*** Education group dummies 
quietly tab educ_grp, gen(educ_)


*** Generate occupation wage premia ***
	* Separate regression for 1980 and 2016, by gender
foreach y of numlist 1980 2016 { 
foreach g in 0 1 { 
	reg logrw educ_2-educ_4 age_2-age_9 black hispanic other native ///
		ib389.occ1990dd if year==`y' & male==`g' [pweight=perwt] 
	parmest, saving("Built/occ_coef`y'_male`g'", replace)
}
}



*** Organize coefficients on occupation dummies ***
foreach y of numlist 1980 2016 { 
foreach g in 0 1 { 
use "Built/occ_coef`y'_male`g'", clear
split parm, p(.)
* Drop the ones that are not occupations
drop if parm2==""
* Change base category so it just shows number rather than #b
replace parm1="389" if parm1=="389b"
destring parm1, replace
rename parm1 occ1990dd
if `g'==0 {
	rename estimate occ_coeff_f`y'
}
if `g'==1 {
	rename estimate occ_coeff_m`y'
}
keep occ1990dd occ_coeff
save "Built/occ_coef`y'_male`g'", replace
}
}
