*************************************************************************
* This do-file takes as input: main_dataset_clean.dta
* It collapses the data to generates employment share, female shares, etc
* by occupation. 
* It also merges in the Atalay et al task data
* Output: occ_share_wide.dta (occupation-level dataset)
*************************************************************************

tempfile temp1 temp2 temp3

use "Built/main_dataset_clean.dta", clear

* Save a tempfile that keeps only the employed
keep if emp==1
save `temp1', replace


*** Collapse by OCCUPATION-YEAR for occ-specific employment, hours, median wages ***
* Employed only:
use `temp1', clear

collapse (sum) emp hours (p50) medlogrw=logrw [fw=perwt], by(occ1990dd year) fast

egen emp_total = sum(emp), by(year)
gen empshare = emp/emp_total

save `temp2', replace


*** Collapse by GENDER-OCCUPATION-YEAR -- for propensities and employment shares

* Using dataset with EVERYONE (including non-employed):
use "Built/main_dataset_clean.dta", clear

replace occ1990dd=9999 if empstat!=1
gen aux=1
collapse (sum) n=aux [fw=perwt], by(occ1990dd male year) fast

egen N_total = sum(n), by(year male)
gen propens=n/N_total

drop N_total 
reshape wide n propens, i(year occ1990dd) j(male)

drop n0 n1 
drop if occ1990dd==9999

save `temp3', replace

*** Merge the two datasets
use `temp2', clear
merge 1:1 occ1990dd year using `temp3', nogen
save `temp2', replace

* Now do for empshare
* Open dataset that only has the employed:
use `temp1', clear

collapse (sum) emp [fw=perwt], by(occ1990dd male year) fast

egen emp_total = sum(emp), by(year male)
gen empshare=emp/emp_total

drop emp_total  
reshape wide emp empshare, i(year occ1990dd) j(male)

save `temp3', replace

*** Merge the two datasets
use `temp2', clear
merge 1:1 occ1990dd year using `temp3', nogen
save `temp2', replace


*** Again but using only college graduates
use "Built/main_dataset_clean.dta", clear
keep if educ==10 | educ==11

replace occ1990dd=9999 if empstat!=1
gen aux=1
collapse (sum) n=aux [fw=perwt], by(occ1990dd male year) fast

egen N_total = sum(n), by(year male)
gen propens_col=n/N_total

drop N_total 
reshape wide n propens_col, i(year occ1990dd) j(male)

drop n0 n1 
drop if occ1990dd==9999

* The ones that had no one are = to missing, but effectively they represent a 
* propensity of zero, so change those:
replace propens_col0 = 0 if propens_col0 == .
replace propens_col1 = 0 if propens_col1 == .

save `temp3', replace

*** Merge the two datasets
use `temp2', clear
merge 1:1 occ1990dd year using `temp3', nogen
save `temp2', replace


*** Again but using only non-college graduates
use "Built/main_dataset_clean.dta", clear
keep if educ!=10 & educ!=11

replace occ1990dd=9999 if empstat!=1
gen aux=1
collapse (sum) n=aux [fw=perwt], by(occ1990dd male year) fast

egen N_total = sum(n), by(year male)
gen propens_noncol=n/N_total

drop N_total 
reshape wide n propens_noncol, i(year occ1990dd) j(male)

drop n0 n1 
drop if occ1990dd==9999

* The ones that had no one are = to missing, but effectively they represent a 
* propensity of zero, so change those:
replace propens_noncol0 = 0 if propens_noncol0 == .
replace propens_noncol1 = 0 if propens_noncol1 == .

save `temp3', replace

*** Merge the two datasets
use `temp2', clear
merge 1:1 occ1990dd year using `temp3', nogen
save `temp2', replace


foreach name in emp empshare propens propens_col propens_noncol {
rename `name'0 `name'_f
rename `name'1 `name'_m
}


*** Allocate occupations to percentiles  of 1980 distribution
foreach y in 1980 {
xtile occ_pctile=medlogrw [w=hours] if year==`y', nq(100)
}
					
drop emp emp_* emp_total* hours* 
	

***************************************
*** Merge in Atalay et al task data *** 	
***************************************
	* NOTE: Original Atalay et al data has been crosswalked to occ1990dd level -- see "pre-cleaning/atalay_data_crosswalking.do"
merge 1:1 occ1990dd year using "Built/atalay_data_by_occ1990dd.dta", ///
	keepusing(ma5_deming_social ma5_deming_social_C) ///
	keep (1 3) nogen
	* Note: Two Dorn codes do not appear in the Atalay data, but they
	* are small (679: Bookbinders and 734: Printing machine operators, n.e.c.)
	

reshape wide empshare medlogrw occ_pctile ///
	empshare_f empshare_m ///
	propens_f propens_m propens_col_f propens_col_m ///
	propens_noncol_f propens_noncol_m ///
	ma5_deming_social ma5_deming_social_C, ///
	i(occ1990dd) j(year)

* Drop variables which have all missings (Atalay et al variables for 2016 mainly)
drop *deming*2016 occ_pctile20*
	
label var occ_pctile1980 "Occupation's percentile ranking in 1980"


*** Merge in occupation fixed effect coefficients for each year
foreach y in 1980 2016 {
foreach g in 0 1 {
merge 1:1 occ1990dd using "Built/occ_coef`y'_male`g'", nogen
}
}

save "Built/occ_share_wide", replace

