
* This do-file builds a dataset of the O*Net 2002 (4.0) ABILITIES, KNOWLEDGE 
* and SKILLS components. 
* It aggregates them to 2000 Census codes by doing a weighted average of all 
* the O*Net occ's that fall into the same 2000 Census code based on OES 
* employment data, and then aggregates to occ1990dd codes again doing a 
* weighted average of all the 2000 codes that fall into the same occ1990dd
* code using OES employment data
  
*************************************************************************
******************************** ONET 2002 ******************************
* ONet 2002 Data in ONET-SOC 2000 Codes

foreach module in abil knowl skill {

if "`module'"=="abil" {
insheet using "orig/ONet 4.0 (2002)/Ability.TXT", clear
* Source: O*Net Resource Center Analyst Database;
* http://www.onetcenter.org/database.html;
* https://www.onetcenter.org/db_releases.html

* Number of dimensions in this module:
local n_dim=52
}

if "`module'"=="knowl" {
insheet using "orig/ONet 4.0 (2002)/Knowledge.txt", clear
* Number of dimensions in this module:
local n_dim=33
}

if "`module'"=="skill" {
insheet using "orig/ONet 4.0 (2002)/Skills.txt", clear
* Number of dimensions in this module:
local n_dim=35
}

label var onetsoccode "O*NET-SOC 2002 Code"

reshape wide datavalue, i(onetsoccode elementid) j(scaleid) string

rename datavalueLV lvl
rename datavalueIM imp

egen dim=group(elementid)

keep onetsoccode lvl imp dim

reshape wide lvl imp, i(onetsoccode) j(dim)

* Rename to make clear that it is from the corresponding module of ONet 2002
forvalues num=1/`n_dim' {
	foreach name in lvl imp {
		rename `name'`num' `module'`num'_`name'_02
	}
}

* Label variables
do "label_`module'.do"

split onetsoccode, gen(soc_) parse(- .)
	* soc_1-soc_2 are the SOC code, soc_3 is the extra bit added by ONet;
sort soc_1 soc_2
rename onetsoccode onet02


*************************************************************************
***************************** ONETs IN 2000 COC *************************
*Re-code ONet data to 2000-COC and aggregate to that level;

*** weighted collapse using employment from 2002 OES

*** Collapse so that each soc_1 soc_2 code appears only once (i.e. combine the
* even finer occupations unique to ONet doing a simple average)

*** Need to slightly aggregate (i.e. ignore last digit) for a few codes in 
* order to match with OES
replace soc_2="1010" if soc_1=="19" & (soc_2=="1011" | soc_2=="1012" | soc_2=="1013")
replace soc_2="4010" if soc_1=="25" & (soc_2=="4011" | soc_2=="4012" | soc_2=="4013")
replace soc_2="3010" if soc_1=="27" & (soc_2=="3011" | soc_2=="3012")
replace soc_2="3020" if soc_1=="27" & (soc_2=="3021" | soc_2=="3022")
replace soc_2="1020" if soc_1=="29" & (soc_2=="1021" | soc_2=="1022" | soc_2=="1023"  | soc_2=="1024")
replace soc_2="9010" if soc_1=="29" & (soc_2=="9011" | soc_2=="9012")
replace soc_2="2130" if soc_1=="47" & (soc_2=="2131" | soc_2=="2132")

collapse *lvl* *imp*, by(soc_1 soc_2)

* Attach employment data at the SOC code level for the year 2002 from the OES:
merge 1:1 soc_1 soc_2 using "orig/OES_national_2002.dta", ///
	keepusing(tot_emp) keep(1 3) nogen 
	
* Attach 2000 Census codes for each SOC code:
merge 1:1 soc_1 soc_2 using "crosswalks/SOC2000_to_occ2000.dta", ///
	keep(1 3) nogen keepusing(occ00_1pct)
* Manually add the codes for the occupations that got slightly aggregated above
* (they all would have corresponded to the same 2000 code anyways)
replace occ00=160 if soc_1=="19" & soc_2=="1010"
replace occ00=240 if soc_1=="25" & soc_2=="4010"
replace occ00=280 if soc_1=="27" & soc_2=="3010"
replace occ00=281 if soc_1=="27" & soc_2=="3020"
replace occ00=301 if soc_1=="29" & soc_2=="1020"
replace occ00=354 if soc_1=="29" & soc_2=="9010"
replace occ00=640 if soc_1=="47" & soc_2=="2130"

	
******** MEANS BY OCC00 (1% file codes) -- employment weighted *********
collapse *lvl* *imp* (rawsum) tot_emp [fw=tot_emp], by(occ00)

* Label variables
do "label_`module'.do"
label variable tot_emp "Total Employment, 2002 OES"


*************************************************************************
********************** ONETs AT occ1990dd level *************************
*************************************************************************

*** weighted collapse using employment from 2002 OES

*** Want to collapse ONet measures to occ1990dd level
* Step 1: Open ONet dataset at the 2000 Census code level and attach occ1990dd codes
* Step 2: Do a weighted average of the 2000 Census codes that fall within the 
* same occ1990dd using the employment that was computed from the OES 

rename occ00_1pct occ00

* Attach occ1990dd codes
merge 1:1 occ00 using "crosswalks/occ00to_mo_dd", ///
	keep(1 3) keepusing(occ1990dd) nogen


collapse *lvl* *imp* [fw=tot_emp], by(occ1990dd)

* Label variables
do "label_`module'.do"

save "Built/onet02_`module'_occ1990dd", replace

}

