
* This do-file builds a dataset of the O*Net 2002 (4.0) WORK CONTEXT Components
* It aggregates them to 2000 Census codes by doing a weighted average of all 
* the O*Net occ's that fall into the same 2000 Census code based on OES 
* employment data, and then aggregates to occ1990dd codes again doing a 
* weighted average of all the 2000 codes that fall into the same occ1990dd
* code using OES employment data


*************************************************************************
******************************** ONET 2002 ******************************
* ONet 2002 Data in ONET-SOC 2000 Codes

insheet using "orig/ONet 4.0 (2002)/WorkContext.TXT", clear
* Source: O*Net Resource Center Analyst Database;
* http://www.onetcenter.org/database.html;
* https://www.onetcenter.org/db_releases.html

label var onetsoccode "O*NET-SOC 2002 Code"

rename datavalue wkcontext

egen dim=group(elementid)

keep onetsoccode wkcontext dim

reshape wide wkcontext, i(onetsoccode) j(dim)

* Rename to make clear that it is from the Work Context module of ONet 2002
forvalues num=1/38 {
	rename wkcontext`num' wkcontext`num'_02
}

* Label variables
label variable wkcontext1_02	"Contact With Others	"
label variable wkcontext2_02	"Deal With External Customers	"
label variable wkcontext3_02	"Coordinate or Lead Others	"
label variable wkcontext4_02	"Responsible for Others' Health and Safety	"
label variable wkcontext5_02	"Responsibility for Outcomes and Results	"
label variable wkcontext6_02	"Frequency of Conflict Situations	"
label variable wkcontext7_02	"Deal With Unpleasant or Angry People	"
label variable wkcontext8_02	"Deal With Physically Aggressive People	"
label variable wkcontext9_02	"Indoors, Environmentally Controlled	"
label variable wkcontext10_02	"Outdoors, Exposed to Weather	"
label variable wkcontext11_02	"Sounds, Noise Levels Are Distracting or Uncomfortable	"
label variable wkcontext12_02	"Very Hot or Cold Temperatures	"
label variable wkcontext13_02	"Extremely Bright or Inadequate Lighting	"
label variable wkcontext14_02	"Exposed to Contaminants	"
label variable wkcontext15_02	"Cramped Work Space, Awkward Positions	"
label variable wkcontext16_02	"Exposed to Whole Body Vibration	"
label variable wkcontext17_02	"Exposed to Radiation	"
label variable wkcontext18_02	"Exposed to Disease or Infections	"
label variable wkcontext19_02	"Exposed to High Places	"
label variable wkcontext20_02	"Exposed to Hazardous Conditions	"
label variable wkcontext21_02	"Exposed to Hazardous Equipment	"
label variable wkcontext22_02	"Exposed to Minor Burns, Cuts, Bites, or Stings	"
label variable wkcontext23_02	"Spend Time Sitting	"
label variable wkcontext24_02	"Spend Time Standing	"
label variable wkcontext25_02	"Spend Time Climbing Ladders, Scaffolds, or Poles	"
label variable wkcontext26_02	"Spend Time Walking and Running	"
label variable wkcontext27_02	"Spend Time Kneeling, Crouching, Stooping, or Crawling?	"
label variable wkcontext28_02	"Spend Time Keeping or Regaining Balance	"
label variable wkcontext29_02	"Spend Time Using Your Hands to Handle, Control, or Feel Objects, Tools, or Controls	"
label variable wkcontext30_02	"Spend Time Bending or Twisting the Body	"
label variable wkcontext31_02	"Spend Time Making Repetitive Motions	"
label variable wkcontext32_02	"Wear Common Protective or Safety Equipment such as Safety Shoes, Glasses, Gloves, Hearing Protection, Hard Hats, or Life Jackets	"
label variable wkcontext33_02	"Wear Specialized Protective or Safety Equipment such as Breathing Apparatus, Safety Harness, Full Protection Suits, or Radiation Protection	"
label variable wkcontext34_02	"Consequence of Error	"
label variable wkcontext35_02	"Degree of Automation	"
label variable wkcontext36_02	"Importance of Being Exact or Accurate	"
label variable wkcontext37_02	"Importance of Repeating Same Tasks	"
label variable wkcontext38_02	"Pace Determined by Speed of Equipment	"

split onetsoccode, gen(soc_) parse(- .)
	* soc_1-soc_2 are the SOC code, soc_3 is the extra bit added by ONet;
sort soc_1 soc_2
rename onetsoccode onet02


*************************************************************************
***************************** ONETs IN 2000 COC *************************
*Re-code ONet data to 2000-COC and aggregate to that level;

*** weighted collapse using employment from 2002 OES

*** Collapse so that each soc_1 soc_2 code appears only once (i.e. combine the
* even finer occupations unique to ONet doing a simple average)

*** Need to slightly aggregate (i.e. ignore last digit) for a few codes in 
* order to match with OES
replace soc_2="1010" if soc_1=="19" & (soc_2=="1011" | soc_2=="1012" | soc_2=="1013")
replace soc_2="4010" if soc_1=="25" & (soc_2=="4011" | soc_2=="4012" | soc_2=="4013")
replace soc_2="3010" if soc_1=="27" & (soc_2=="3011" | soc_2=="3012")
replace soc_2="3020" if soc_1=="27" & (soc_2=="3021" | soc_2=="3022")
replace soc_2="1020" if soc_1=="29" & (soc_2=="1021" | soc_2=="1022" | soc_2=="1023"  | soc_2=="1024")
replace soc_2="9010" if soc_1=="29" & (soc_2=="9011" | soc_2=="9012")
replace soc_2="2130" if soc_1=="47" & (soc_2=="2131" | soc_2=="2132")

collapse *wkcontext*, by(soc_1 soc_2)

* Attach employment data at the SOC code level for the year 2002 from the OES:
merge 1:1 soc_1 soc_2 using "orig/OES_national_2002.dta", ///
	keep(1 3) nogen keepusing(tot_emp)
	
* Attach 2000 Census codes for each SOC code:
merge 1:1 soc_1 soc_2 using "crosswalks/SOC2000_to_occ2000.dta", ///
	keep(1 3) nogen keepusing(occ00_1pct)
* Manually add the codes for the occupations that got slightly aggregated above
* (they all would have corresponded to the same 2000 code anyways)
replace occ00=160 if soc_1=="19" & soc_2=="1010"
replace occ00=240 if soc_1=="25" & soc_2=="4010"
replace occ00=280 if soc_1=="27" & soc_2=="3010"
replace occ00=281 if soc_1=="27" & soc_2=="3020"
replace occ00=301 if soc_1=="29" & soc_2=="1020"
replace occ00=354 if soc_1=="29" & soc_2=="9010"
replace occ00=640 if soc_1=="47" & soc_2=="2130"

	
******** MEANS BY OCC00 (1% file codes) -- employment weighted *********
collapse *wkcontext* (rawsum) tot_emp [fw=tot_emp], by(occ00)

* Label variables
label variable wkcontext1_02	"Contact With Others	"
label variable wkcontext2_02	"Deal With External Customers	"
label variable wkcontext3_02	"Coordinate or Lead Others	"
label variable wkcontext4_02	"Responsible for Others' Health and Safety	"
label variable wkcontext5_02	"Responsibility for Outcomes and Results	"
label variable wkcontext6_02	"Frequency of Conflict Situations	"
label variable wkcontext7_02	"Deal With Unpleasant or Angry People	"
label variable wkcontext8_02	"Deal With Physically Aggressive People	"
label variable wkcontext9_02	"Indoors, Environmentally Controlled	"
label variable wkcontext10_02	"Outdoors, Exposed to Weather	"
label variable wkcontext11_02	"Sounds, Noise Levels Are Distracting or Uncomfortable	"
label variable wkcontext12_02	"Very Hot or Cold Temperatures	"
label variable wkcontext13_02	"Extremely Bright or Inadequate Lighting	"
label variable wkcontext14_02	"Exposed to Contaminants	"
label variable wkcontext15_02	"Cramped Work Space, Awkward Positions	"
label variable wkcontext16_02	"Exposed to Whole Body Vibration	"
label variable wkcontext17_02	"Exposed to Radiation	"
label variable wkcontext18_02	"Exposed to Disease or Infections	"
label variable wkcontext19_02	"Exposed to High Places	"
label variable wkcontext20_02	"Exposed to Hazardous Conditions	"
label variable wkcontext21_02	"Exposed to Hazardous Equipment	"
label variable wkcontext22_02	"Exposed to Minor Burns, Cuts, Bites, or Stings	"
label variable wkcontext23_02	"Spend Time Sitting	"
label variable wkcontext24_02	"Spend Time Standing	"
label variable wkcontext25_02	"Spend Time Climbing Ladders, Scaffolds, or Poles	"
label variable wkcontext26_02	"Spend Time Walking and Running	"
label variable wkcontext27_02	"Spend Time Kneeling, Crouching, Stooping, or Crawling?	"
label variable wkcontext28_02	"Spend Time Keeping or Regaining Balance	"
label variable wkcontext29_02	"Spend Time Using Your Hands to Handle, Control, or Feel Objects, Tools, or Controls	"
label variable wkcontext30_02	"Spend Time Bending or Twisting the Body	"
label variable wkcontext31_02	"Spend Time Making Repetitive Motions	"
label variable wkcontext32_02	"Wear Common Protective or Safety Equipment such as Safety Shoes, Glasses, Gloves, Hearing Protection, Hard Hats, or Life Jackets	"
label variable wkcontext33_02	"Wear Specialized Protective or Safety Equipment such as Breathing Apparatus, Safety Harness, Full Protection Suits, or Radiation Protection	"
label variable wkcontext34_02	"Consequence of Error	"
label variable wkcontext35_02	"Degree of Automation	"
label variable wkcontext36_02	"Importance of Being Exact or Accurate	"
label variable wkcontext37_02	"Importance of Repeating Same Tasks	"
label variable wkcontext38_02	"Pace Determined by Speed of Equipment	"

label variable tot_emp "Total Employment, 2002 OES"


*************************************************************************
********************** ONETs AT occ1990dd level *************************
*************************************************************************

*** weighted collapse using employment from 2002 OES

*** Want to collapse ONet measures to occ1990dd level
* Step 1: Open ONet dataset at the 2000 Census code level and attach occ1990dd codes
* Step 2: Do a weighted average of the 2000 Census codes that fall within the 
* same occ1990dd using the employment that was computed from the OES 

use "Built/onet02_wkcontext_occ00_1pct", clear

rename occ00_1pct occ00

* Attach occ1990dd codes
merge 1:1 occ00 using "crosswalks/occ00to_mo_dd", ///
	keep(1 3) keepusing(occ1990dd) nogen


collapse *wkcontext* [fw=tot_emp], by(occ1990dd)

* Label variables
label variable wkcontext1_02	"Contact With Others	"
label variable wkcontext2_02	"Deal With External Customers	"
label variable wkcontext3_02	"Coordinate or Lead Others	"
label variable wkcontext4_02	"Responsible for Others' Health and Safety	"
label variable wkcontext5_02	"Responsibility for Outcomes and Results	"
label variable wkcontext6_02	"Frequency of Conflict Situations	"
label variable wkcontext7_02	"Deal With Unpleasant or Angry People	"
label variable wkcontext8_02	"Deal With Physically Aggressive People	"
label variable wkcontext9_02	"Indoors, Environmentally Controlled	"
label variable wkcontext10_02	"Outdoors, Exposed to Weather	"
label variable wkcontext11_02	"Sounds, Noise Levels Are Distracting or Uncomfortable	"
label variable wkcontext12_02	"Very Hot or Cold Temperatures	"
label variable wkcontext13_02	"Extremely Bright or Inadequate Lighting	"
label variable wkcontext14_02	"Exposed to Contaminants	"
label variable wkcontext15_02	"Cramped Work Space, Awkward Positions	"
label variable wkcontext16_02	"Exposed to Whole Body Vibration	"
label variable wkcontext17_02	"Exposed to Radiation	"
label variable wkcontext18_02	"Exposed to Disease or Infections	"
label variable wkcontext19_02	"Exposed to High Places	"
label variable wkcontext20_02	"Exposed to Hazardous Conditions	"
label variable wkcontext21_02	"Exposed to Hazardous Equipment	"
label variable wkcontext22_02	"Exposed to Minor Burns, Cuts, Bites, or Stings	"
label variable wkcontext23_02	"Spend Time Sitting	"
label variable wkcontext24_02	"Spend Time Standing	"
label variable wkcontext25_02	"Spend Time Climbing Ladders, Scaffolds, or Poles	"
label variable wkcontext26_02	"Spend Time Walking and Running	"
label variable wkcontext27_02	"Spend Time Kneeling, Crouching, Stooping, or Crawling?	"
label variable wkcontext28_02	"Spend Time Keeping or Regaining Balance	"
label variable wkcontext29_02	"Spend Time Using Your Hands to Handle, Control, or Feel Objects, Tools, or Controls	"
label variable wkcontext30_02	"Spend Time Bending or Twisting the Body	"
label variable wkcontext31_02	"Spend Time Making Repetitive Motions	"
label variable wkcontext32_02	"Wear Common Protective or Safety Equipment such as Safety Shoes, Glasses, Gloves, Hearing Protection, Hard Hats, or Life Jackets	"
label variable wkcontext33_02	"Wear Specialized Protective or Safety Equipment such as Breathing Apparatus, Safety Harness, Full Protection Suits, or Radiation Protection	"
label variable wkcontext34_02	"Consequence of Error	"
label variable wkcontext35_02	"Degree of Automation	"
label variable wkcontext36_02	"Importance of Being Exact or Accurate	"
label variable wkcontext37_02	"Importance of Repeating Same Tasks	"
label variable wkcontext38_02	"Pace Determined by Speed of Equipment	"

save "Built/onet02_wkcontext_occ1990dd", replace
